@@ -57,7 +57,7 @@ def run(
 ):
     from phiterm.conf.phi_conf import PhiConf, PhiWsData
     from phiterm.databox.databox_operator import run_command
-    from phiterm.utils.dotenv import load_dotenv
+    from phiterm.utils.load_env import load_env
 
     if print_debug_log:
         set_log_level_to_debug()
@@ -76,7 +76,7 @@ def run(
         return
 
     # Load environment from .env
-    load_dotenv(workspace_root=active_ws_data.ws_root_path)
+    load_env(dotenv_dir=active_ws_data.ws_root_path)
 
     target_app: Optional[str] = None
     target_env: Optional[str] = None
