@@ -90,7 +90,7 @@ def run(
     """
     from phiterm.conf.phi_conf import PhiConf, PhiWsData
     from phiterm.workflow.wf_operator import run_workflow
-    from phiterm.utils.dotenv import load_dotenv
+    from phiterm.utils.load_env import load_env
 
     if print_debug_log:
         set_log_level_to_debug()
@@ -109,7 +109,7 @@ def run(
         return
 
     # Load environment from .env
-    load_dotenv(workspace_root=active_ws_data.ws_root_path)
+    load_env(dotenv_dir=active_ws_data.ws_root_path)
 
     target_env: Optional[WorkflowEnv] = None
     target_app: Optional[str] = app_name
@@ -175,7 +175,7 @@ def ls(
 ):
     from phiterm.conf.phi_conf import PhiConf, PhiWsData
     from phiterm.workflow.wf_operator import list_workflows
-    from phiterm.utils.dotenv import load_dotenv
+    from phiterm.utils.load_env import load_env
 
     if print_debug_log:
         set_log_level_to_debug()
@@ -194,7 +194,7 @@ def ls(
         return
 
     # Load environment from .env
-    load_dotenv(workspace_root=active_ws_data.ws_root_path)
+    load_env(dotenv_dir=active_ws_data.ws_root_path)
 
     list_workflows(
         wf_description=workflow,
