@@ -106,15 +106,16 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
     _dot_git_folder = ws_root_path.joinpath(".git")
     _dot_git_exists = _dot_git_folder.exists()
     if _dot_git_exists:
-        # logger.debug(".git folder exists... deleting")
-        _dot_git_exists = not rmdir_recursive(_dot_git_folder)
-    # logger.debug(f"_dot_git_exists: {_dot_git_exists}")
+        logger.debug(f"Deleting {_dot_git_folder}")
+        try:
+            _dot_git_exists = not rmdir_recursive(_dot_git_folder)
+        except Exception as e:
+            logger.warning(f"Failed to delete {_dot_git_folder}: {e}")
+            logger.info("Please delete the .git folder manually")
+            pass
 
     # validate that a workspace config file exists
     ws_config_file_path: Path = get_ws_config_file_path(ws_root_path)
-    # logger.debug(
-    #     "Checking if workspace config file exists: {}".format(ws_config_file_path)
-    # )
     if not (ws_config_file_path.exists() and ws_config_file_path.is_file()):
         logger.error(f"Could not find workspace config at: {ws_config_file_path}")
         return False
@@ -959,3 +960,77 @@ def set_workspace_as_active(ws_name: Optional[str], refresh: bool = True) -> boo
     phi_conf.active_ws_name = new_active_ws_name
     print_info("Active workspace updated")
     return True
+
+
+def print_workspace_status(
+    ws_data: PhiWsData,
+    target_env: Optional[str] = None,
+    target_config: Optional[WorkspaceConfigType] = None,
+    target_name: Optional[str] = None,
+    target_type: Optional[str] = None,
+    target_app: Optional[str] = None,
+    dry_run: Optional[bool] = False,
+    auto_confirm: Optional[bool] = False,
+) -> None:
+    """Print the Workspace status. This is called from `phi ws status`"""
+    from phidata.infra.docker.config import DockerConfig
+    from phidata.infra.k8s.config import K8sConfig
+    from phidata.infra.aws.config import AwsConfig
+
+    if ws_data is None or ws_data.ws_config is None:
+        logger.error("WorkspaceConfig invalid")
+        return
+
+    ws_config: WorkspaceConfig = ws_data.ws_config
+    # Set the local environment variables before processing configs
+    ws_config.set_local_env()
+
+    configs_to_patch: List[InfraConfig] = filter_and_prep_configs(
+        ws_config=ws_config,
+        target_env=target_env,
+        target_config=target_config,
+        order="create",
+    )
+
+    num_configs_to_patch = len(configs_to_patch)
+    num_configs_patched = 0
+    for config in configs_to_patch:
+        logger.debug(f"Patching {config.__class__.__name__}")
+        if isinstance(config, DockerConfig):
+            from phiterm.docker.docker_operator import patch_docker_config
+
+            # print_docker_config_status(
+            #     config=config,
+            #     name_filter=target_name,
+            #     type_filter=target_type,
+            #     app_filter=target_app,
+            #     dry_run=dry_run,
+            #     auto_confirm=auto_confirm,
+            # )
+            num_configs_patched += 1
+        if isinstance(config, K8sConfig):
+            from phiterm.k8s.k8s_operator import patch_k8s_config
+
+            # print_k8s_config_status(
+            #     config=config,
+            #     name_filter=target_name,
+            #     type_filter=target_type,
+            #     app_filter=target_app,
+            #     dry_run=dry_run,
+            #     auto_confirm=auto_confirm,
+            # )
+            num_configs_patched += 1
+        if isinstance(config, AwsConfig):
+            from phiterm.aws.aws_operator import patch_aws_config
+
+            # print_aws_config_status(
+            #     config=config,
+            #     name_filter=target_name,
+            #     type_filter=target_type,
+            #     app_filter=target_app,
+            #     dry_run=dry_run,
+            #     auto_confirm=auto_confirm,
+            # )
+            num_configs_patched += 1
+        # white space between runs
+        print_info("")
